@@ -130,7 +130,7 @@ class Command(Assertion):
 
         return self._stderr
 
-    def any_out_activated(self):
+    def _any_out_activated(self):
         return any([self.stdout, self.stderr])
 
     def run(self):
@@ -150,7 +150,7 @@ class Command(Assertion):
         stdout = decorate_out_with_logger(self._stdout, 'out', config.stdout)
         stderr = decorate_out_with_logger(self._stderr, 'err', config.stderr)
 
-        if self.any_out_activated():
+        if self._any_out_activated():
             self.log_status()
 
         logger = PrefixLogger(self.log, '%s%s ' % (INDENTST, self.name))
@@ -185,25 +185,30 @@ class Command(Assertion):
     def sync_returncode(self):
         return self.sp.returncode
 
-    def current_elapsed(self):
+    def _current_elapsed(self):
         return time.time() - self.tinit
 
     def elapsed(self):
         return self.tend - self.tinit
 
     def on_time(self):
-        return self.current_elapsed() < self.timeout
+        return self._current_elapsed() < self.timeout
 
     def wait(self):
+        def terminate():
+            if self.terminated:
+                return
+
+            msg = '{0}$name timeout exceeded: {1:1.2f}s >= {2:1.2f}s, terminating...'
+            self.log.debug(msg.format(INDENTST, self._current_elapsed(),
+                                      self.timeout))
+            self.terminate()
+
         if self.timeout is not None:
             while self.on_time() and not self.terminated:
                 time.sleep(0.05)
 
-            if not self.terminated:
-                self.log.debug('{0}$name timeout exceeded: {1:1.2f}s >= {2:1.2f}s, terminating...'.format(
-                        INDENTST, self.current_elapsed(), self.timeout))
-
-                self.sp.terminate()
+            terminate()
 
         self.sp.wait()
         self._returncode = self.sp.returncode
@@ -214,6 +219,7 @@ class Command(Assertion):
             return
 
         self.sp.terminate()
+        assert self.terminated
 
     def __unicode__(self):
 #        cmd = self.sp or repr(self.cmdline)
@@ -239,7 +245,6 @@ class Command(Assertion):
 #        if self.cwd != self.interpolator.testdir:
 #            cwd = ' cwd:{0}'.format(self.cwd)
 
-
         return u"Command {0!r} code ({1}:{2}){3}{4}".format(
             self.cmdline, expected, returncode, time, cwd)
 
