@@ -48,6 +48,12 @@ class Task(Printable):
 
         self.assertions = []
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
+        pass
+
     @classmethod
     def get_index(cls, objid):
         try:
